@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::ReadLine::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::ReadLine::VERSION = '0.30';
+  $Reply::Plugin::ReadLine::VERSION = '0.31';
 }
 use strict;
 use warnings;
@@ -31,12 +31,15 @@ sub new {
         $history
     );
 
-    if ($self->{term}->ReadLine eq 'Term::ReadLine::Perl5') {
+    $self->{rl_gnu} = $self->{term}->ReadLine eq 'Term::ReadLine::Gnu';
+    $self->{rl_perl5} = $self->{term}->ReadLine eq 'Term::ReadLine::Perl5';
+
+    if ($self->{rl_perl5}) {
         # output compatible with Term::ReadLine::Gnu
         $readline::rl_scroll_nextline = 0;
     }
 
-    if ($self->{term}->ReadLine eq ('Term::ReadLine::Gnu' or 'Term::ReadLine::Perl5')) {
+    if ($self->{rl_perl5} || $self->{rl_gnu}) {
         $self->{term}->StifleHistory($opts{history_length})
             if defined $opts{history_length} && $opts{history_length} >= 0;
     }
@@ -71,7 +74,7 @@ sub DESTROY {
     return if defined $self->{history_length} && $self->{history_length} == 0;
 
     # XXX support more later
-    return unless $self->{term}->ReadLine eq ('Term::ReadLine::Gnu' or 'Term::ReadLine::Perl5');
+    return unless ($self->{rl_gnu} || $self->{rl_perl5});
 
     $self->{term}->WriteHistory($self->{history_file})
         or warn "Couldn't write history to $self->{history_file}";
@@ -84,7 +87,7 @@ sub _register_tab_complete {
 
     weaken(my $weakself = $self);
 
-    if ($term->ReadLine eq 'Term::ReadLine::Gnu') {
+    if ($self->{rl_gnu}) {
         $term->Attribs->{attempted_completion_function} = sub {
             my ($text, $line, $start, $end) = @_;
 
@@ -101,7 +104,7 @@ sub _register_tab_complete {
         };
     }
 
-    if ($term->ReadLine eq 'Term::ReadLine::Perl5') {
+    if ($self->{rl_perl5}) {
         $term->Attribs->{completion_function} = sub {
             my ($text, $line, $start) = @_;
             my $end = $start + length($text);
@@ -127,7 +130,7 @@ Reply::Plugin::ReadLine - use Term::ReadLine for user input
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
